#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// ATR Breakout from TASC June 2016.
    /// </summary>
    [Description("ATR Breakout from TASC June 2016.")]
    public class ATRBreakout : Strategy
    {
        #region Variables
		private double 	priceRangeHi 	= 70;
		private double 	priceRangeLo 	= 15;
		private double	priceRangeMin	= 5;
		private double	volumeRangeMin	= 1000000;
		private int		atrPeriod		= 14;
		private int		maPeriod		= 100;
		private double	wideRange		= 1.5;
		private int		trailStop		= 2;
		private double	high			= 0;
        #endregion

        protected override void Initialize()
        {
			Add(SMA(maPeriod));
			Add(ATR(atrPeriod));
			Add(VOL());
			
			SetTrailStop(trailStop);
			
            CalculateOnBarClose = true;
        }

        protected override void OnBarUpdate()
        {
			if (Close[0] < priceRangeHi
				&& Close[0] > priceRangeLo
				&& Math.Abs(High[0] - Low[0]) >= priceRangeMin
				&& Volume[0] >= volumeRangeMin
				&& ATR(atrPeriod)[0] >= MAX(ATR(atrPeriod), atrPeriod)[0]
				&& CrossAbove(Close, SMA(maPeriod), 1)
				&& Math.Abs(High[0] - Low[0]) >= Math.Abs(High[1] - Low[1]) * wideRange
				&& Volume[0] > Volume[1])
			{
				high = High[0];
			}
			
			if (high != 0
				&& Close[0] >= high + .5)
			{
				EnterLongStop(High[0]);
			}
        }

        #region Properties
        [Description("Highest level for price action")]
        [GridCategory("Parameters")]
        public double PriceRangeHi
        {
            get { return priceRangeHi; }
            set { priceRangeHi = Math.Max(1, value); }
        }
		[Description("Lowest level for price action")]
        [GridCategory("Parameters")]
        public double PriceRangeLo
        {
            get { return priceRangeLo; }
            set { priceRangeLo = Math.Max(1, value); }
        }
		[Description("Minimum movement of current bar in point value")]
        [GridCategory("Parameters")]
        public double PriceRangeMin
        {
            get { return priceRangeMin; }
            set { priceRangeMin = Math.Max(1, value); }
        }
		[Description("ATR Period")]
        [GridCategory("Parameters")]
        public int AtrPeriod
        {
            get { return atrPeriod; }
            set { atrPeriod = Math.Max(1, value); }
        }
		[Description("MA Period")]
        [GridCategory("Parameters")]
        public int MaPeriod
        {
            get { return maPeriod; }
            set { maPeriod = Math.Max(1, value); }
        }
		[Description("Range of current bar against previous bar")]
        [GridCategory("Parameters")]
        public double WideRange
        {
            get { return wideRange; }
            set { wideRange = Math.Max(1, value); }
        }
		[Description("Trailing Stop value in point value")]
        [GridCategory("Parameters")]
        public int TrailStop
        {
            get { return trailStop; }
            set { trailStop = Math.Max(1, value); }
        }
        #endregion
    }
}
